 .. _development:

DIPY development
================

Contents:

.. toctree::
   :maxdepth: 2

   intro
   gitwash/index
   make_release
   commit_codes
   coding_style_guideline
   python3

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

